﻿using IRaCIS.Core.Domain.Models;
using MassTransit.Futures.Contracts;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace IRaCIS.Core.Domain.FileRecord
{
    [Comment("项目文件 - 定稿记录表")]
    [Table("TrialFinalRecord")]
    public class TrialFinalRecord : BaseFullAuditEntity
    {
        public Guid TrialId { get; set; }

        [Comment("关联项目文件类型")]
        public Guid TrialFileTypeId { get; set; }


        public string Name { get; set; }

        public string Version { get; set; }


        #region 文件控制
        public int State { get; set; }

        [Comment("是否授权查看")]
        public bool IsAuthorizedView { get; set; }
        #endregion


        [Comment("定稿PDF")]
        public Guid PDFTrialFileRecordId { get; set; }

        [Comment("定稿Word")]
        public Guid WordTrialFileRecordId { get; set; }

        [Comment("签名页")]
        public Guid SignTrialFileRecordId { get; set; }

        [Comment("历史记录")]
        public Guid HistoryTrialFileRecordId { get; set; }


        #region 废弃

        [Comment("定稿PDF名字")]
        public string PDFName { get; set; }

        public string PDFPath { get; set; }

        [Comment("定稿Word名字")]
        public string WordName { get; set; }

        public string WordPath { get; set; }

        [Comment("签名页名字")]
        public string SignFileName { get; set; }

        public string SignFilePath { get; set; }



        [Comment("历史记录名字")]
        public string HistoryRecordFileName { get; set; }

        public string HistoryRecordFilePath { get; set; }

        #endregion


    }



    [Comment("项目文件 - 一般文件记录表")]
    [Table("TrialNormalFileRecord")]
    public class TrialNormalFileRecord : BaseFullAuditEntity
    {
        public Guid TrialId { get; set; }

        [Comment("关联项目文件类型")]
        public Guid TrialFileTypeId { get; set; }

        #region 文件控制
        public int State { get; set; }

        [Comment("是否授权查看")]
        public bool IsAuthorizedView { get; set; }
        #endregion


        [Comment("关联具体的文件记录，记录里面有大小，格式，名称")]
        public Guid TrialFileRecordId { get; set; }

        #region 废弃

        public string FileName { get; set; }

        [StringLength(1000)]
        public string FilePath { get; set; }

        public string FileSize { get; set; }

        public string FileFormat { get; set; }

        #endregion


    }


    [Comment("项目文件 - 培训记录表")]
    [Table("TrialTrianingRecord")]
    public class TrialTrianingRecord : BaseFullAuditEntity
    {
        public Guid TrialId { get; set; }

        [Comment("关联项目文件类型")]
        public Guid TrialFileTypeId { get; set; }

        #region 培训记录相关字段
        public DateOnly TrianingDate { get; set; }

        public int TrianingCount { get; set; }

        [Comment("培训效果")]
        public int TrianingState { get; set; }

        #endregion

        #region 文件控制
        public int State { get; set; }

        [Comment("是否授权查看")]
        public bool IsAuthorizedView { get; set; }

        #endregion

        [Comment("关联具体的文件记录，记录里面有大小，格式，名称")]
        public Guid TrialFileRecordId { get; set; }

        public string Note { get; set; }

    }

    [Comment("项目文件 - 文件记录表")]
    [Table("TrialFileRecord")]
    public class TrialFileRecord : BaseFullAuditEntity
    {
        public Guid TrialId { get; set; }

        public string FileName { get; set; }

        [StringLength(1000)]
        public string FilePath { get; set; }

        public string FileSize { get; set; }

        public string FileFormat { get; set; }

    }
}
